@@ -46,6 +46,9 @@ providers_list = {
     'blogtruyen_com': [
         r'blogtruyen\.com/.',
     ],
+    'catmanga_org': [
+        r'catmanga\.org/series/.'
+    ],
     'cdmnet_com_br': [
         r'cdmnet\.com\.br/titulos/.',
         r'centraldemangas.online/titulos/.'
@@ -95,6 +98,9 @@ providers_list = {
     'funmanga_com': [
         r'funmanga\.com/.',
     ],
+    'genkan_io': [
+        r'genkan\.io/manga/.'
+    ],
     'gmanga_me': [
         r'gmanga\.me/mangas/.',
     ],
@@ -298,11 +304,6 @@ providers_list = {
         r'mysticalmerries\.com/manga/.',
         r'mangarave\.com/manga/.',
         r'thetopcomic\.com/manga/.',
-    ],
-    # 'jaiminisbox_com': [
-    #     r'jaiminisbox\.com/reader/series/.',
-    # ],
-    'jaiminisbox_net': [
         r'jaiminisbox\.net/manga/.',
     ],
     'japscan_com': [
