@@ -9,7 +9,7 @@ class TranslateWebToonsCom(Provider, Std):
     def get_chapter_index(self) -> str:
         return self.re.search(r'\bepisodeNo=(\d+)', self.chapter).group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         return self.http_get(self.get_url())
 
     def get_manga_name(self) -> str:
